<?php
/**
 * Plugin Name: Aurora Heatmap (Installer)
 * Plugin URI:  https://market.seous.info/aurora-heatmap
 * Description: Beautiful like an aurora! A simple WordPress heatmap that can be completed with just a plugin.
 * Version:     0.1.10
 * Author:      R3098
 * Author URI:  https://seous.info/
 * License:     GPLv2
 * Text Domain: aurora-heatmap-premium-installer
 * Domain Path: /languages
 *
 * @package aurora-heatmap
 * @copyright 2019-2024 R3098 <info@seous.info>
 * @version 0.1.10
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! function_exists( 'aurora_heatmap_conflict' ) ) {
	/**
	 * Aurora Heatmap Conflict
	 */
	function aurora_heatmap_conflict() {
		die( esc_html__( 'Fail to activate. Another version of Aurora Heatmap is already active.', 'aurora-heatmap-premium-installer' ) );
	}
}

// Check conflict.
if ( defined( 'AURORA_HEATMAP' ) ) {
	if ( is_admin() ) {
		register_activation_hook( __FILE__, 'aurora_heatmap_conflict' );
	}
	return;
} else {
	// Set constant to check conflict.
	define( 'AURORA_HEATMAP', __FILE__ );
}

// Translation for plugin headers.
function () {
	__( 'Aurora Heatmap (Installer)', 'aurora-heatmap-premium-installer' );
	__( 'Beautiful like an aurora! A simple WordPress heatmap that can be completed with just a plugin.', 'aurora-heatmap-premium-installer' );
};


load_plugin_textdomain( 'aurora-heatmap-premium-installer', false, basename( __DIR__ ) . '/languages' );

if ( ! function_exists( 'aurora_heatmap_fs' ) ) {
	/**
	 * Create a helper function for easy SDK access.
	 */
	function aurora_heatmap_fs() {
		global $aurora_heatmap_fs;

		if ( ! isset( $aurora_heatmap_fs ) ) {
			// Include Freemius SDK.
			require_once __DIR__ . '/premium/freemius/start.php';

			$aurora_heatmap_fs = fs_dynamic_init(
				array(
					'id'                  => '4533',
					'slug'                => 'aurora-heatmap',
					'type'                => 'plugin',
					'public_key'          => 'pk_5f10aeda0c7e7deb9b4217a4f732c',
					'is_premium'          => true,
					'premium_suffix'      => 'Premium',
					// If your plugin is a serviceware, set this option to false.
					'has_premium_version' => true,
					'has_addons'          => false,
					'has_paid_plans'      => true,
					'menu'                => array(
						'slug'    => 'aurora-heatmap-premium',
						'contact' => true,
						'support' => false,
						'parent'  => array(
							'slug' => 'options-general.php',
						),
					),
				)
			);

			// Translators: JSON Object format to freemius override_i18n.
			// Translators: See https://github.com/Freemius/wordpress-sdk/blob/master/includes/i18n.php
			// Translators: Example for '{"hey-x": "Hello %s,"}'.
			$override = _x( '{}', 'freemius-override-i18n', 'aurora-heatmap-premium-installer' );
			// Json decode to PHP assoc array.
			$override = json_decode( $override, true );

			if ( $override ) {
				$aurora_heatmap_fs->override_i18n( $override );
			}
		}

		return $aurora_heatmap_fs;
	}

	// Init Freemius.
	aurora_heatmap_fs();
	// Signal that SDK was initiated.
	do_action( 'aurora_heatmap_fs_loaded' );
}

if ( ! function_exists( 'aurora_heatmap_uninstall' ) ) {
	/**
	 * Aurora Heatmap Uninstall
	 */
	function aurora_heatmap_uninstall() {
		// If installed two or more, keep tables and options.
		require_once ABSPATH . 'wp-admin/includes/plugin.php';
		$installed = 0;
		foreach ( array_keys( get_plugins() ) as $plugin ) {
			if ( 'aurora-heatmap.php' !== basename( $plugin ) ) {
				continue;
			}
			++$installed;
			if ( 1 < $installed ) {
				return;
			}
		}

		// Delete option, cron, DB tables.
		global $wpdb;
		delete_option( 'aurora_heatmap_option' );
		wp_clear_scheduled_hook( 'aurora_heatmap_cron_daily' );
		$wpdb->query( "DROP TABLE IF EXISTS {$wpdb->prefix}ahm_events" ); // phpcs:ignore WordPress.DB.DirectDatabaseQuery
		$wpdb->query( "DROP TABLE IF EXISTS {$wpdb->prefix}ahm_pages" ); // phpcs:ignore WordPress.DB.DirectDatabaseQuery
		$wpdb->query( "DROP TABLE IF EXISTS {$wpdb->prefix}ahm_norm" ); // phpcs:ignore WordPress.DB.DirectDatabaseQuery
		$wpdb->query( "DROP TABLE IF EXISTS {$wpdb->prefix}ahm_unread" ); // phpcs:ignore WordPress.DB.DirectDatabaseQuery
	}
}

global $aurora_heatmap_fs;

if ( $aurora_heatmap_fs->is_on() ) {
	aurora_heatmap_fs()->add_action( 'after_uninstall', 'aurora_heatmap_uninstall' );
} else {
	register_uninstall_hook( AURORA_HEATMAP, 'aurora_heatmap_uninstall' );
}

require_once __DIR__ . '/premium/class-aurora-heatmap-installer.php';

register_activation_hook( AURORA_HEATMAP, 'Aurora_Heatmap_Installer::activation' );
register_deactivation_hook( AURORA_HEATMAP, 'Aurora_Heatmap_Installer::deactivation' );
add_action(
	'init',
	function () {
		Aurora_Heatmap_Installer::get_instance();
	}
);

/* vim: set ts=4 sw=4 sts=4 noet: */
